@@ -7,7 +7,7 @@ validate names with.
 from re import Pattern as _Pattern
 from re import compile as _compile
 
-DEFAULT_PATTERN = _compile("^\\w+$")
+DEFAULT_PATTERN = _compile("^[\\w\\:]+$")
 CHANNEL_PATTERN = _compile("^[a-z0-9-_.]+$")
 
 
