@@ -17,6 +17,7 @@ from vcorelib.logging import LoggerType as _LoggerType
 
 # internal
 from runtimepy.net.metrics import ConnectionMetrics
+from runtimepy.primitives.byte_order import DEFAULT_BYTE_ORDER, ByteOrder
 
 BinaryMessage = _Union[bytes, bytearray, memoryview]
 
@@ -27,6 +28,8 @@ class Connection(_LoggerMixin, _ABC):
     uses_text_tx_queue = True
     uses_binary_tx_queue = True
 
+    byte_order: ByteOrder = DEFAULT_BYTE_ORDER
+
     def __init__(self, logger: _LoggerType) -> None:
         """Initialize this connection."""
 
@@ -55,6 +58,11 @@ class Connection(_LoggerMixin, _ABC):
     def init(self) -> None:
         """Initialize this instance."""
 
+    def log_metrics(self, label: str = "conn") -> None:
+        """Log connection metrics."""
+        self.logger.info("(%s) tx: %s", label, self.metrics.tx)
+        self.logger.info("(%s) rx: %s", label, self.metrics.rx)
+
     async def async_init(self) -> bool:
         """A runtime initialization routine (executes during 'process')."""
         return True
